/* --------------------------------------------------------------
 social_share.js 2016-05-09
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

/**
 * Widget that enables the social sharing support
 * (e.g.: Facebook, Twitter, Google+)
 */
gambio.widgets.module(
	'social_share',

	['xhr'],

	function(data) {

		'use strict';

// ########## VARIABLE INITIALIZATION ########## 

		var $this = $(this),
			defaults = {
				// URL from where the social share markup gets delivered.
				url: jse.core.registry.get('tplPath') + 'social_sharing/get.php'
			},
			options = $.extend(true, {}, defaults, data),
			module = {};


// ########## EVENT HANDLER ##########

		/**
		 * Click handler for the social sharing buttons / links
		 * @private
		 */
		var _clickHandler = function() {
			var $self = $(this),
				dataset = $self.data();
			
			// Get the current configuration
			dataset = dataset.social_share || $self.parseModuleData('social_share');
			
			// Collect data for the backend
			dataset.url = location.href;
			dataset.title = document.title;
			dataset.product_image = $('.swiper-slide-active img').attr('src');

			// Get the markup
			jse.libs.xhr.ajax({url: options.url, data: dataset, dataType: 'html'}).done(function(result) {
				var $button = $(result),
					iframe = $button.is('iframe'),
					$preloader = $('<div class="preloader" ></div>');

				// Appends a click handler if the new state is "off"
				if (dataset.state !== 'on') {
					$self.one('click', _clickHandler);
					dataset.state = 'on';
				}

				if (iframe) {
					// If it is an iframe, show a preloader
					// and remove it, after the iframe has loaded
					$button.one('load', function() {
						$preloader.remove();
					});

					$self
						.data('social_share', dataset)
						.empty()
						.append($preloader)
						.append($button);

				} else {
					// Else just append the button
					$self
						.data('social_share', dataset)
						.empty()
						.append($button);
				}

			});
		};


// ########## INITIALIZATION ##########

		/**
		 * Init function of the widget
		 * @constructor
		 */
		module.init = function(done) {

			// In first instance perform the
			// action that will be performed
			// on click also
			$this
				.find('[data-social_share-service]')
				.each(_clickHandler);

			done();
		};

		// Return data to widget engine
		return module;
	});